==> knative-model-6.3.0-sources.jar: io/fabric8/knative/flows/v1/ParallelSubscriptionStatusFluentImpl.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.knative.internal.pkg.apis.ConditionFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParallelSubscriptionStatusFluentImpl<A extends ParallelSubscriptionStatusFluent<A>> extends BaseFluent<A> implements ParallelSubscriptionStatusFluent<A>{
  public ParallelSubscriptionStatusFluentImpl() {
  }
  public ParallelSubscriptionStatusFluentImpl(ParallelSubscriptionStatus instance) {
    this.withReady(instance.getReady()); 
    this.withSubscription(instance.getSubscription()); 
  }
  private ConditionBuilder ready;
  private ObjectReferenceBuilder subscription;
  
  /**
   * This method has been deprecated, please use method buildReady instead.
   * @return The buildable object.
   */
  @Deprecated
  public Condition getReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  public Condition buildReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  public A withReady(Condition ready) {
    _visitables.get("ready").remove(this.ready);
    if (ready!=null){ this.ready= new ConditionBuilder(ready); _visitables.get("ready").add(this.ready);} else { this.ready = null; _visitables.get("ready").remove(this.ready); } return (A) this;
  }
  public Boolean hasReady() {
    return this.ready != null;
  }
  public ParallelSubscriptionStatusFluent.ReadyNested<A> withNewReady() {
    return new ParallelSubscriptionStatusFluentImpl.ReadyNestedImpl();
  }
  public ParallelSubscriptionStatusFluent.ReadyNested<A> withNewReadyLike(Condition item) {
    return new ParallelSubscriptionStatusFluentImpl.ReadyNestedImpl(item);
  }
  public ParallelSubscriptionStatusFluent.ReadyNested<A> editReady() {
    return withNewReadyLike(getReady());
  }
  public ParallelSubscriptionStatusFluent.ReadyNested<A> editOrNewReady() {
    return withNewReadyLike(getReady() != null ? getReady(): new ConditionBuilder().build());
  }
  public ParallelSubscriptionStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item) {
    return withNewReadyLike(getReady() != null ? getReady(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSubscription instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  public ObjectReference buildSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  public A withSubscription(ObjectReference subscription) {
    _visitables.get("subscription").remove(this.subscription);
    if (subscription!=null){ this.subscription= new ObjectReferenceBuilder(subscription); _visitables.get("subscription").add(this.subscription);} else { this.subscription = null; _visitables.get("subscription").remove(this.subscription); } return (A) this;
  }
  public Boolean hasSubscription() {
    return this.subscription != null;
  }
  public ParallelSubscriptionStatusFluent.SubscriptionNested<A> withNewSubscription() {
    return new ParallelSubscriptionStatusFluentImpl.SubscriptionNestedImpl();
  }
  public ParallelSubscriptionStatusFluent.SubscriptionNested<A> withNewSubscriptionLike(ObjectReference item) {
    return new ParallelSubscriptionStatusFluentImpl.SubscriptionNestedImpl(item);
  }
  public ParallelSubscriptionStatusFluent.SubscriptionNested<A> editSubscription() {
    return withNewSubscriptionLike(getSubscription());
  }
  public ParallelSubscriptionStatusFluent.SubscriptionNested<A> editOrNewSubscription() {
    return withNewSubscriptionLike(getSubscription() != null ? getSubscription(): new ObjectReferenceBuilder().build());
  }
  public ParallelSubscriptionStatusFluent.SubscriptionNested<A> editOrNewSubscriptionLike(ObjectReference item) {
    return withNewSubscriptionLike(getSubscription() != null ? getSubscription(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ParallelSubscriptionStatusFluentImpl that = (ParallelSubscriptionStatusFluentImpl) o;
    if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
    if (subscription != null ? !subscription.equals(that.subscription) :that.subscription != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  subscription,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (subscription != null) { sb.append("subscription:"); sb.append(subscription); }
    sb.append("}");
    return sb.toString();
  }
  class ReadyNestedImpl<N> extends ConditionFluentImpl<ParallelSubscriptionStatusFluent.ReadyNested<N>> implements ParallelSubscriptionStatusFluent.ReadyNested<N>,Nested<N>{
    ReadyNestedImpl(Condition item) {
      this.builder = new ConditionBuilder(this, item);
    }
    ReadyNestedImpl() {
      this.builder = new ConditionBuilder(this);
    }
    ConditionBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluentImpl.this.withReady(builder.build());
    }
    public N endReady() {
      return and();
    }
    
  }
  class SubscriptionNestedImpl<N> extends ObjectReferenceFluentImpl<ParallelSubscriptionStatusFluent.SubscriptionNested<N>> implements ParallelSubscriptionStatusFluent.SubscriptionNested<N>,Nested<N>{
    SubscriptionNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    SubscriptionNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluentImpl.this.withSubscription(builder.build());
    }
    public N endSubscription() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/ParallelSubscriptionStatusFluentImpl.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.knative.internal.pkg.apis.ConditionFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParallelSubscriptionStatusFluentImpl<A extends ParallelSubscriptionStatusFluent<A>> extends BaseFluent<A> implements ParallelSubscriptionStatusFluent<A>{
  public ParallelSubscriptionStatusFluentImpl() {
  }
  public ParallelSubscriptionStatusFluentImpl(ParallelSubscriptionStatus instance) {
    if (instance != null) {
      this.withReady(instance.getReady());
      this.withSubscription(instance.getSubscription());
    }
  }
  private ConditionBuilder ready;
  private ObjectReferenceBuilder subscription;
  
  /**
   * This method has been deprecated, please use method buildReady instead.
   * @return The buildable object.
   */
  @Deprecated
  public Condition getReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  public Condition buildReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  public A withReady(Condition ready) {
    _visitables.get("ready").remove(this.ready);
    if (ready!=null){ this.ready= new ConditionBuilder(ready); _visitables.get("ready").add(this.ready);} else { this.ready = null; _visitables.get("ready").remove(this.ready); } return (A) this;
  }
  public Boolean hasReady() {
    return this.ready != null;
  }
  public ParallelSubscriptionStatusFluentImpl.ReadyNested<A> withNewReady() {
    return new ParallelSubscriptionStatusFluentImpl.ReadyNestedImpl();
  }
  public ParallelSubscriptionStatusFluentImpl.ReadyNested<A> withNewReadyLike(Condition item) {
    return new ParallelSubscriptionStatusFluentImpl.ReadyNestedImpl(item);
  }
  public ParallelSubscriptionStatusFluentImpl.ReadyNested<A> editReady() {
    return withNewReadyLike(getReady());
  }
  public ParallelSubscriptionStatusFluentImpl.ReadyNested<A> editOrNewReady() {
    return withNewReadyLike(getReady() != null ? getReady(): new ConditionBuilder().build());
  }
  public ParallelSubscriptionStatusFluentImpl.ReadyNested<A> editOrNewReadyLike(Condition item) {
    return withNewReadyLike(getReady() != null ? getReady(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSubscription instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  public ObjectReference buildSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  public A withSubscription(ObjectReference subscription) {
    _visitables.get("subscription").remove(this.subscription);
    if (subscription!=null){ this.subscription= new ObjectReferenceBuilder(subscription); _visitables.get("subscription").add(this.subscription);} else { this.subscription = null; _visitables.get("subscription").remove(this.subscription); } return (A) this;
  }
  public Boolean hasSubscription() {
    return this.subscription != null;
  }
  public ParallelSubscriptionStatusFluentImpl.SubscriptionNested<A> withNewSubscription() {
    return new ParallelSubscriptionStatusFluentImpl.SubscriptionNestedImpl();
  }
  public ParallelSubscriptionStatusFluentImpl.SubscriptionNested<A> withNewSubscriptionLike(ObjectReference item) {
    return new ParallelSubscriptionStatusFluentImpl.SubscriptionNestedImpl(item);
  }
  public ParallelSubscriptionStatusFluentImpl.SubscriptionNested<A> editSubscription() {
    return withNewSubscriptionLike(getSubscription());
  }
  public ParallelSubscriptionStatusFluentImpl.SubscriptionNested<A> editOrNewSubscription() {
    return withNewSubscriptionLike(getSubscription() != null ? getSubscription(): new ObjectReferenceBuilder().build());
  }
  public ParallelSubscriptionStatusFluentImpl.SubscriptionNested<A> editOrNewSubscriptionLike(ObjectReference item) {
    return withNewSubscriptionLike(getSubscription() != null ? getSubscription(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParallelSubscriptionStatusFluentImpl that = (ParallelSubscriptionStatusFluentImpl) o;
    if (!java.util.Objects.equals(ready, that.ready)) return false;

    if (!java.util.Objects.equals(subscription, that.subscription)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  subscription,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (subscription != null) { sb.append("subscription:"); sb.append(subscription); }
    sb.append("}");
    return sb.toString();
  }
  class ReadyNestedImpl<N> extends ConditionFluentImpl<ParallelSubscriptionStatusFluentImpl.ReadyNested<N>> implements ParallelSubscriptionStatusFluentImpl.ReadyNested<N>,Nested<N>{
    ReadyNestedImpl(Condition item) {
      this.builder = new ConditionBuilder(this, item);
    }
    ReadyNestedImpl() {
      this.builder = new ConditionBuilder(this);
    }
    ConditionBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluentImpl.this.withReady(builder.build());
    }
    public N endReady() {
      return and();
    }
    
  }
  class SubscriptionNestedImpl<N> extends ObjectReferenceFluentImpl<ParallelSubscriptionStatusFluentImpl.SubscriptionNested<N>> implements ParallelSubscriptionStatusFluentImpl.SubscriptionNested<N>,Nested<N>{
    SubscriptionNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    SubscriptionNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluentImpl.this.withSubscription(builder.build());
    }
    public N endSubscription() {
      return and();
    }
    
  }
  
}
